# The core sub-package must be archful because it is required to be in
# libdir by the platform, but we have no natives, so suppress debuginfo
%global debug_package %{nil}

%global git_tag R2_12_0

%global droplets droplets

Name:      eclipse-emf
Version:   2.12.0
Release:   %mkrel 2
Group:     Development/Java
Summary:   Eclipse Modeling Framework (EMF) Eclipse plug-in

License:   EPL
URL:       http://www.eclipse.org/modeling/emf/
Source0:   http://git.eclipse.org/c/emf/org.eclipse.emf.git/snapshot/org.eclipse.emf-%{git_tag}.tar.xz
# This is a template used by tycho for generating parent pom
Source1:   parent-pom.xml

# look inside correct directory for platform docs
Patch0:    eclipse-emf-platform-docs-location.patch
# Include documentation search index, exclude non-existing files
Patch1:    fix-build-properties.patch
# Fix test dependency on missing RAP bundles
Patch2:    remove-rap-dependency.patch

BuildRequires: tycho >= 0.23.0
BuildRequires: tycho-extras >= 0.23.0
BuildRequires: eclipse-filesystem
BuildRequires: eclipse-pde
BuildRequires: eclipse-xsd

%description
The Eclipse Modeling Framework (EMF) allows developers to build tools and
other applications based on a structured data model. From a model
specification described in XMI, EMF provides tools and run-time support to
produce a set of Java classes for the model, along with a set of adapter
classes that enable viewing and command-based editing of the model, and a
basic editor.

%package   core
Epoch:     1
Summary:   Eclipse EMF Core
Requires:  eclipse-filesystem

%description core
EMF bundles required by eclipse-platform.

%package   runtime
Summary:   Eclipse Modeling Framework (EMF) Eclipse plug-in

# Obsoletes/provides added in F22
Obsoletes: %{name} < %{version}-%{release}
Provides:  %{name} = %{version}-%{release}

%description runtime
The Eclipse Modeling Framework (EMF) allows developers to build tools and
other applications based on a structured data model. From a model
specification described in XMI, EMF provides tools and run-time support to
produce a set of Java classes for the model, along with a set of adapter
classes that enable viewing and command-based editing of the model, and a
basic editor.

%package   tests
Summary:   Eclipse EMF Tests

%description tests
Tests for the Eclipse Modeling Framework (EMF) plug-in.

%package   sdk
Summary:   Eclipse EMF SDK

%description sdk
Documentation and developer resources for the Eclipse Modeling Framework
(EMF) plug-in.

%package   examples
Summary:   Eclipse EMF examples
Requires:  %{name}-sdk = %{version}-%{release}

%description examples
Install-able versions of the example projects from the SDKs that demonstrate
how to use the Eclipse Modeling Framework (EMF) plug-ins.

%prep
%setup -q -n org.eclipse.emf-%{git_tag}

find . -type f -name "*.jar" -exec rm {} \;
find . -type f -name "*.class" -exec rm {} \;

%patch0
%patch1
%patch2

# Fix spurious exec perms on license
chmod 0644 features/org.eclipse.emf.license-feature/rootfiles/epl-v10.html

# TODO: ODA, GWT, Xtext and RAP components are not packaged.
find -maxdepth 2 -type d -name "*.xcore*" -exec rm -r {} \;
find -maxdepth 2 -type d -name "*.xtext*" -exec rm -r {} \;
find -maxdepth 2 -type d -name "*.oda*" -exec rm -r {} \;
find -maxdepth 2 -type d -name "*.rap*" -exec rm -r {} \;
find -maxdepth 2 -type d -name "*.gwt*" -exec rm -r {} \;

# Insert pom templates
mkdir pom-templates
cp -p %{SOURCE1} pom-templates/.

# Generate pom.xml
mv doc/org.eclipse.emf.examples.jet.article2 examples
xmvn -o org.eclipse.tycho:tycho-pomgenerator-plugin:generate-poms -DgroupId=org.eclipse.emf
find features -name pom.xml -exec sed -i -e 's/^  <groupId>\(.*\)</  <groupId>\1.features</' {} \;
find tests -name pom.xml -exec sed -i -e 's/^  <groupId>\(.*\)</  <groupId>\1.tests</' {} \;
find examples -name pom.xml -exec sed -i -e 's/^  <groupId>\(.*\)</  <groupId>\1.examples</' {} \;
find doc -name pom.xml -exec sed -i -e 's/^  <groupId>\(.*\)</  <groupId>\1.doc</' {} \;
%pom_add_plugin "org.eclipse.tycho.extras:tycho-eclipserun-plugin:0.23.0" doc/org.eclipse.emf.doc \
  "<executions><execution><goals><goal>eclipse-run</goal></goals><phase>process-sources</phase></execution></executions><configuration><appArgLine>-consolelog -debug -application org.eclipse.ant.core.antRunner -quiet -buildfile buildDoc.xml</appArgLine><repositories><repository><id>luna</id><layout>p2</layout><url>http://download.eclipse.org/releases/luna</url></repository></repositories><dependencies><dependency><artifactId>org.eclipse.ant.core</artifactId><type>eclipse-plugin</type></dependency><dependency><artifactId>org.apache.ant</artifactId><type>eclipse-plugin</type></dependency><dependency><artifactId>org.eclipse.help.base</artifactId><type>eclipse-plugin</type></dependency></dependencies></configuration>"

# Remove broken refs to source bundles
%pom_xpath_remove "includes[@id='org.eclipse.emf.source']" features/org.eclipse.emf.sdk-feature/feature.xml
%pom_xpath_remove "includes[@id='org.eclipse.emf.doc.source']" features/org.eclipse.emf.sdk-feature/feature.xml
%pom_xpath_remove "includes[@id='org.eclipse.emf.examples.source']" examples/org.eclipse.emf.examples-feature/feature.xml

# Disable modules unneeded for tycho build
%pom_disable_module 'features/org.eclipse.emf.all-feature'
%pom_disable_module 'releng/org.eclipse.emf.build-feature'
%pom_disable_module 'releng/org.eclipse.emf.base.build-feature'

%mvn_package "::pom::" __noinstall
%mvn_package "org.eclipse.emf.tests:" tests
%mvn_package "::jar:{sources,sources-feature}:" sdk
%mvn_package ":org.eclipse.emf.{sdk,example.installer}" sdk
%mvn_package "org.eclipse.emf.doc:" sdk
%mvn_package "org.eclipse.emf.features:org.eclipse.emf.{base,common,ecore}" core
%mvn_package "org.eclipse.emf:org.eclipse.emf.{common,ecore,ecore.change,ecore.xmi}" core
%mvn_package "org.eclipse.emf.examples:" examples
%mvn_package ":" runtime

%build
%mvn_build -f -j -- -DforceContextQualifier=$(echo v%{version}-%{release} | tr '.' '_' | tr -d -c '[:alnum:]_-')

%install
%mvn_install

# Move to libdir due to being part of core platform
install -d -m 755 %{buildroot}%{_libdir}/eclipse
mv %{buildroot}%{_datadir}/eclipse/%{droplets}/emf-core/eclipse/{plugins,features} %{buildroot}%{_libdir}/eclipse
rm -r %{buildroot}%{_datadir}/eclipse/%{droplets}/emf-core

# Fixup metadata
sed -i -e 's|%{_datadir}/eclipse/%{droplets}/emf-core/eclipse|%{_libdir}/eclipse|' %{buildroot}%{_datadir}/maven-metadata/eclipse-emf-core.xml
sed -i -e 's|%{_datadir}/eclipse/%{droplets}/emf-core/eclipse/features/|%{_libdir}/eclipse/features/|' \
       -e 's|%{_datadir}/eclipse/%{droplets}/emf-core/eclipse/plugins/|%{_libdir}/eclipse/plugins/|' .mfiles-core
sed -i -e '/%{droplets}/d' .mfiles-core

%files core -f .mfiles-core

%files runtime -f .mfiles-runtime

%files tests -f .mfiles-tests

%files sdk -f .mfiles-sdk

%files examples -f .mfiles-examples



%changelog
* Sun Jul 17 2016 neoclust <neoclust> 2.12.0-2.mga6
+ Revision: 1042352
- Try to rebuild cleanly on armv5

* Mon Jun 13 2016 daviddavid <daviddavid> 2.12.0-1.mga6
+ Revision: 1021337
- Update to Neon release: 2.12.0 Final

* Mon Jun 13 2016 pterjan <pterjan> 2.12.0-0.1.git2021583.2.mga6
+ Revision: 1021330
- Do not use date as ContextQualifier, this breaks when different arches are not built on the same day

* Tue May 10 2016 daviddavid <daviddavid> 2.12.0-0.1.git2021583.1.mga6
+ Revision: 1012043
- Update to latest Neon snapshot (2.12.0)

* Fri Apr 29 2016 daviddavid <daviddavid> 2.11.2-1.mga6
+ Revision: 1007768
- Update to Mars.2 release

* Wed Mar 02 2016 neoclust <neoclust> 2.11.1-10.mga6
+ Revision: 983071
- Removal of noarch tag
- Second rebuild of the java stack
- Rebuild with fixed deps on i586
- Try to rebuild with fixed deps
- Rebuild against fixed tycho
- Rebuild against fixed eclipse
- First rebuild of the java stack
- sync package eclipse-emf with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Fri Dec 26 2014 pterjan <pterjan> 2.10.1-2.mga5
+ Revision: 806295
- Clean rebuild
- Sync with Fedora 21 (update to 2.10.1)
- Restore

  + sander85 <sander85>
    - Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 2.9.1-4.mga5
+ Revision: 739373
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.9.1-3.mga5
+ Revision: 678939
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 2.9.1-2.mga4
+ Revision: 542185
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 dmorgan <dmorgan> 2.9.1-1.mga4
+ Revision: 497045
- New version

* Wed Sep 25 2013 dmorgan <dmorgan> 2.9.0-1.mga4
+ Revision: 485938
- Update to Kepler release.
- 974108: Remove versions and timestamps from EMF filenames.

* Wed Sep 25 2013 dmorgan <dmorgan> 2.9.0-0.1.git352e28.1.mga4
+ Revision: 485789
- New version

* Sat Jan 19 2013 dmorgan <dmorgan> 2.8.1-4.mga3
+ Revision: 389639
- Clean spec file

* Fri Jan 11 2013 umeabot <umeabot> 2.8.1-3.mga3
+ Revision: 349415
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 06 2012 dmorgan <dmorgan> 2.8.1-2.mga3
+ Revision: 327416
- New version 2.8.1

* Thu Dec 06 2012 dmorgan <dmorgan> 2.8.0-15.mga3
+ Revision: 327298
- Revert to 2.8.0-15

* Wed Dec 05 2012 dmorgan <dmorgan> 2.8.1-1.mga3
+ Revision: 327067
- New version
- Rebuild against new eclipse

* Sat Sep 15 2012 dmorgan <dmorgan> 2.8.0-10.mga3
+ Revision: 294050
- Bump release as this is now a standalone package
- New version

* Mon May 16 2011 ahmad <ahmad> 2.6.0-3.mga1
+ Revision: 99297
- Fix sub-packages groups (mga#1302)

* Tue May 10 2011 dmorgan <dmorgan> 2.6.0-2.mga1
+ Revision: 96813
- Fix java requires
- imported package eclipse-emf


* Thu Aug 5 2010 Charley Wang <chwang@redhat.com> - 2.6.0-2
- Build SDK features, fix patches. 
- EMFAntTest failing, cannot find /example in osgi bundle

* Mon Jul 19 2010 Charley Wang <chwang@redhat.com> - 2.6.0-1
- Update to 2.6.0

* Sat Sep 19 2009 Mat Booth <fedora@matbooth.co.uk> - 2.5.0-4
- Re-enable jar repacking now that RHBZ #461854 has been resolved.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jul 02 2009 Mat Booth <fedora@matbooth.co.uk> 2.5.0-2
- SDK requires PDE for example plug-in projects.

* Sun Jun 28 2009 Mat Booth <fedora@matbooth.co.uk> 2.5.0-1
- Update to 2.5.0 final release (Galileo).
- Build the features seperately to allow for a saner %%files section.

* Fri May 22 2009 Alexander Kurtakov <akurtako@redhat.com> 2.5.0-0.2.RC1
- Update to 2.5.0 RC1.
- Use %%global instead of %%define. 

* Sat Apr 18 2009 Mat Booth <fedora@matbooth.co.uk> 2.5.0-0.1.M6
- Update to Milestone 6 release of 2.5.0.
- Require Eclipse 3.5.0.

* Tue Apr 7 2009 Alexander Kurtakov <akurtako@redhat.com> 2.4.2-3
- Fix directory ownership.

* Mon Mar 23 2009 Alexander Kurtakov <akurtako@redhat.com> 2.4.2-2
- Rebuild to not ship p2 context.xml.
- Remove context.xml from %%files section.

* Sat Feb 28 2009 Mat Booth <fedora@matbooth.co.uk> 2.4.2-1
- Update for Ganymede SR2.

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 03 2009 Mat Booth <fedora@matbooth.co.uk> 2.4.1-4
- Make context qualifier the same as upstream.

* Sat Jan 10 2009 Mat Booth <fedora@matbooth.co.uk> 2.4.1-3
- Removed AOT bits and change package names to what they used to be.
- Obsolete standalone package.

* Tue Dec 23 2008 Mat Booth <fedora@matbooth.co.uk> 2.4.1-2
- Build example installer plugins using the source from the tarball instead of
  trying to get the examples from source control a second time.

* Fri Dec 12 2008 Mat Booth <fedora@matbooth.co.uk> 2.4.1-1
- Initial release, based on eclipse-gef spec file, but with disabled AOT
  compiled bits because of RHBZ #477707.
